%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LaTeX style for publication in Journal of Digital Forensics, Security and Law
%
% © Libor Polčák, Faculty of Information Technology, Brno University of
% Technology, Brno, the Czech Republic, ipolcak@fit.vutbr.cz
%
% This style was created following the formating guide lines at
% https://commons.erau.edu/jdfsl/submission-guidelines.html. Use at your own risk
%
% Licence: GPLv2
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
%
% Modified 2018-04-24 by Glenn S. Dardick
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ProvidesClass{jdfsl}[2014/08/04 version 0.2 JDFSL style template]
\NeedsTeXFormat{LaTeX2e}

% This class extends the article class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions \relax
\LoadClass[twocolumn,11pt]{article}

% Page size and margins
\RequirePackage[letterpaper,twoside,left=1in,right=0.88in,top=1in,bottom=1in]{geometry}
\setlength{\columnsep}{0.25in}

% Redefine maketitle (based on standard article @maketitle)
\def\@maketitle{%
  \newpage
  \null
  \vskip 2em%
  \begin{center}%
  \let \footnote \thanks
    \vskip 12pt%
    {\bf {\LARGE \expandafter\MakeUppercase\expandafter{\@title} \par}}%
    \vskip 6pt%
    {\large
      \begin{tabular}[t]{c}%
        \@author
      \end{tabular}\par}%
    \vskip 0.5ex%
			{\@institute}%
    \vskip 12pt%
		{\bf \large ABSTRACT}%
  \end{center}%
    \vskip -0.5em%
		{\@abstract \par}%
    \vskip 1em%
		{{\bf Keywords}: \@keywords}%
  \par
  \vskip 1.5em}


\def\@institute{No institute defined}
\newcommand{\institute}[1]{\gdef\@institute{#1}}

\def\@abstract{No abstract defined}
\renewcommand{\abstract}[1]{\gdef\@abstract{#1}}

\def\@keywords{No keywords defined}
\newcommand{\keywords}[1]{\gdef\@keywords{#1}}


% Headings
\usepackage[center,medium,compact]{titlesec}
\titleformat{\section}[block]{\Large\bfseries\center}{\thetitle.}{1em}{\MakeUppercase}


% References
\usepackage{apacite}
